Class: Google::Apis::ResellerV1::ResellerService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::ResellerV1::ResellerService
- Defined in:
- lib/google/apis/reseller_v1/service.rb
Overview
Google Workspace Reseller API
Perform common functions that are available on the Channel Services console at scale, like placing orders and viewing customer information
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://reseller.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#activate_subscription(customer_id, subscription_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ResellerV1::Subscription
Activates a subscription previously suspended by the reseller.
-
#change_subscription_plan(customer_id, subscription_id, change_plan_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ResellerV1::Subscription
Updates a subscription plan.
-
#change_subscription_renewal_settings(customer_id, subscription_id, renewal_settings_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ResellerV1::Subscription
Updates a user license's renewal settings.
-
#change_subscription_seats(customer_id, subscription_id, seats_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ResellerV1::Subscription
Updates a subscription's user license settings.
-
#delete_subscription(customer_id, subscription_id, deletion_type, fields: nil, quota_user: nil, options: nil) {|result, err| ... }
Cancels, suspends, or transfers a subscription to direct.
-
#get_customer(customer_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ResellerV1::Customer
Gets a customer account.
-
#get_subscription(customer_id, subscription_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ResellerV1::Subscription
Gets a specific subscription.
-
#getwatchdetails_resellernotify(fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ResellerV1::ResellernotifyGetwatchdetailsResponse
Returns all the details of the watch corresponding to the reseller.
-
#initialize ⇒ ResellerService
constructor
A new instance of ResellerService.
-
#insert_customer(customer_object = nil, customer_auth_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ResellerV1::Customer
Orders a new customer's account.
-
#insert_subscription(customer_id, subscription_object = nil, action: nil, customer_auth_token: nil, source_sku_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ResellerV1::Subscription
Creates or transfer a subscription.
-
#list_subscriptions(customer_auth_token: nil, customer_id: nil, customer_name_prefix: nil, max_results: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ResellerV1::Subscriptions
Lists of subscriptions managed by the reseller.
-
#patch_customer(customer_id, customer_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ResellerV1::Customer
Updates a customer account's settings.
-
#register_resellernotify(service_account_email_address: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ResellerV1::ResellernotifyResource
Registers a Reseller for receiving notifications.
-
#start_subscription_paid_service(customer_id, subscription_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ResellerV1::Subscription
Immediately move a 30-day free trial subscription to a paid service subscription.
-
#suspend_subscription(customer_id, subscription_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ResellerV1::Subscription
Suspends an active subscription.
-
#unregister_resellernotify(service_account_email_address: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ResellerV1::ResellernotifyResource
Unregisters a Reseller for receiving notifications.
-
#update_customer(customer_id, customer_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ResellerV1::Customer
Updates a customer account's settings.
Constructor Details
#initialize ⇒ ResellerService
Returns a new instance of ResellerService.
48 49 50 51 52 53 |
# File 'lib/google/apis/reseller_v1/service.rb', line 48 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-reseller_v1', client_version: Google::Apis::ResellerV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
41 42 43 |
# File 'lib/google/apis/reseller_v1/service.rb', line 41 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
46 47 48 |
# File 'lib/google/apis/reseller_v1/service.rb', line 46 def quota_user @quota_user end |
Instance Method Details
#activate_subscription(customer_id, subscription_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ResellerV1::Subscription
Activates a subscription previously suspended by the reseller. If you did not suspend the customer subscription and it is suspended for any other reason, such as for abuse or a pending ToS acceptance, this call will not reactivate the customer subscription.
349 350 351 352 353 354 355 356 357 358 |
# File 'lib/google/apis/reseller_v1/service.rb', line 349 def activate_subscription(customer_id, subscription_id, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'apps/reseller/v1/customers/{customerId}/subscriptions/{subscriptionId}/activate', ) command.response_representation = Google::Apis::ResellerV1::Subscription::Representation command.response_class = Google::Apis::ResellerV1::Subscription command.params['customerId'] = customer_id unless customer_id.nil? command.params['subscriptionId'] = subscription_id unless subscription_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#change_subscription_plan(customer_id, subscription_id, change_plan_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ResellerV1::Subscription
Updates a subscription plan. Use this method to update a plan for a 30-day trial or a flexible plan subscription to an annual commitment plan with monthly or yearly payments. How a plan is updated differs depending on the plan and the products. For more information, see the description in manage subscriptions.
396 397 398 399 400 401 402 403 404 405 406 407 |
# File 'lib/google/apis/reseller_v1/service.rb', line 396 def change_subscription_plan(customer_id, subscription_id, change_plan_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'apps/reseller/v1/customers/{customerId}/subscriptions/{subscriptionId}/changePlan', ) command.request_representation = Google::Apis::ResellerV1::ChangePlanRequest::Representation command.request_object = change_plan_request_object command.response_representation = Google::Apis::ResellerV1::Subscription::Representation command.response_class = Google::Apis::ResellerV1::Subscription command.params['customerId'] = customer_id unless customer_id.nil? command.params['subscriptionId'] = subscription_id unless subscription_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#change_subscription_renewal_settings(customer_id, subscription_id, renewal_settings_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ResellerV1::Subscription
Updates a user license's renewal settings. This is applicable for accounts with annual commitment plans only. For more information, see the description in manage subscriptions.
443 444 445 446 447 448 449 450 451 452 453 454 |
# File 'lib/google/apis/reseller_v1/service.rb', line 443 def change_subscription_renewal_settings(customer_id, subscription_id, renewal_settings_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'apps/reseller/v1/customers/{customerId}/subscriptions/{subscriptionId}/changeRenewalSettings', ) command.request_representation = Google::Apis::ResellerV1::RenewalSettings::Representation command.request_object = renewal_settings_object command.response_representation = Google::Apis::ResellerV1::Subscription::Representation command.response_class = Google::Apis::ResellerV1::Subscription command.params['customerId'] = customer_id unless customer_id.nil? command.params['subscriptionId'] = subscription_id unless subscription_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#change_subscription_seats(customer_id, subscription_id, seats_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ResellerV1::Subscription
Updates a subscription's user license settings. For more information about updating an annual commitment plan or a flexible plan subscription’s licenses, see Manage Subscriptions.
490 491 492 493 494 495 496 497 498 499 500 501 |
# File 'lib/google/apis/reseller_v1/service.rb', line 490 def change_subscription_seats(customer_id, subscription_id, seats_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'apps/reseller/v1/customers/{customerId}/subscriptions/{subscriptionId}/changeSeats', ) command.request_representation = Google::Apis::ResellerV1::Seats::Representation command.request_object = seats_object command.response_representation = Google::Apis::ResellerV1::Subscription::Representation command.response_class = Google::Apis::ResellerV1::Subscription command.params['customerId'] = customer_id unless customer_id.nil? command.params['subscriptionId'] = subscription_id unless subscription_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_subscription(customer_id, subscription_id, deletion_type, fields: nil, quota_user: nil, options: nil) {|result, err| ... }
This method returns an undefined value.
Cancels, suspends, or transfers a subscription to direct.
536 537 538 539 540 541 542 543 544 |
# File 'lib/google/apis/reseller_v1/service.rb', line 536 def delete_subscription(customer_id, subscription_id, deletion_type, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'apps/reseller/v1/customers/{customerId}/subscriptions/{subscriptionId}', ) command.params['customerId'] = customer_id unless customer_id.nil? command.params['subscriptionId'] = subscription_id unless subscription_id.nil? command.query['deletionType'] = deletion_type unless deletion_type.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_customer(customer_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ResellerV1::Customer
Gets a customer account. Use this operation to see a customer account already in your reseller management, or to see the minimal account information for an existing customer that you do not manage. For more information about the API response for existing customers, see retrieving a customer account.
84 85 86 87 88 89 90 91 92 |
# File 'lib/google/apis/reseller_v1/service.rb', line 84 def get_customer(customer_id, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'apps/reseller/v1/customers/{customerId}', ) command.response_representation = Google::Apis::ResellerV1::Customer::Representation command.response_class = Google::Apis::ResellerV1::Customer command.params['customerId'] = customer_id unless customer_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_subscription(customer_id, subscription_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ResellerV1::Subscription
Gets a specific subscription. The subscriptionId can be found using the
Retrieve all reseller subscriptions method.
For more information about retrieving a specific subscription, see the
information descrived in manage subscriptions.
581 582 583 584 585 586 587 588 589 590 |
# File 'lib/google/apis/reseller_v1/service.rb', line 581 def get_subscription(customer_id, subscription_id, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'apps/reseller/v1/customers/{customerId}/subscriptions/{subscriptionId}', ) command.response_representation = Google::Apis::ResellerV1::Subscription::Representation command.response_class = Google::Apis::ResellerV1::Subscription command.params['customerId'] = customer_id unless customer_id.nil? command.params['subscriptionId'] = subscription_id unless subscription_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#getwatchdetails_resellernotify(fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ResellerV1::ResellernotifyGetwatchdetailsResponse
Returns all the details of the watch corresponding to the reseller.
247 248 249 250 251 252 253 254 |
# File 'lib/google/apis/reseller_v1/service.rb', line 247 def getwatchdetails_resellernotify(fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'apps/reseller/v1/resellernotify/getwatchdetails', ) command.response_representation = Google::Apis::ResellerV1::ResellernotifyGetwatchdetailsResponse::Representation command.response_class = Google::Apis::ResellerV1::ResellernotifyGetwatchdetailsResponse command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#insert_customer(customer_object = nil, customer_auth_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ResellerV1::Customer
Orders a new customer's account. Before ordering a new customer account,
establish whether the customer account already exists using the customers.
get If the customer account exists as a direct Google account or as
a resold customer account from another reseller, use the customerAuthToken\
as described in order a resold account for an existing customer. For more information about ordering a new customer
account, see order a new customer account. After
creating a new customer account, you must provision a user as an administrator.
The customer's administrator is required to sign in to the Admin console and
sign the G Suite via Reseller agreement to activate the account. Resellers are
prohibited from signing the G Suite via Reseller agreement on the customer's
behalf. For more information, see order a new customer account
.
135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/google/apis/reseller_v1/service.rb', line 135 def insert_customer(customer_object = nil, customer_auth_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'apps/reseller/v1/customers', ) command.request_representation = Google::Apis::ResellerV1::Customer::Representation command.request_object = customer_object command.response_representation = Google::Apis::ResellerV1::Customer::Representation command.response_class = Google::Apis::ResellerV1::Customer command.query['customerAuthToken'] = customer_auth_token unless customer_auth_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#insert_subscription(customer_id, subscription_object = nil, action: nil, customer_auth_token: nil, source_sku_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ResellerV1::Subscription
Creates or transfer a subscription. Create a subscription for a customer's
account that you ordered using the Order a new customer account method. For more information about creating a subscription for different
payment plans, see manage subscriptions.\
If you did not order the customer's account using the customer insert method,
use the customer's customerAuthToken when creating a subscription for that
customer. If transferring a G Suite subscription with an associated Google
Drive or Google Vault subscription, use the batch operation to
transfer all of these subscriptions. For more information, see how to
transfer subscriptions.
642 643 644 645 646 647 648 649 650 651 652 653 654 655 |
# File 'lib/google/apis/reseller_v1/service.rb', line 642 def insert_subscription(customer_id, subscription_object = nil, action: nil, customer_auth_token: nil, source_sku_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'apps/reseller/v1/customers/{customerId}/subscriptions', ) command.request_representation = Google::Apis::ResellerV1::Subscription::Representation command.request_object = subscription_object command.response_representation = Google::Apis::ResellerV1::Subscription::Representation command.response_class = Google::Apis::ResellerV1::Subscription command.params['customerId'] = customer_id unless customer_id.nil? command.query['action'] = action unless action.nil? command.query['customerAuthToken'] = customer_auth_token unless customer_auth_token.nil? command.query['sourceSkuId'] = source_sku_id unless source_sku_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_subscriptions(customer_auth_token: nil, customer_id: nil, customer_name_prefix: nil, max_results: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ResellerV1::Subscriptions
Lists of subscriptions managed by the reseller. The list can be all
subscriptions, all of a customer's subscriptions, or all of a customer's
transferable subscriptions. Optionally, this method can filter the response by
a customerNamePrefix. For more information, see manage subscriptions.
706 707 708 709 710 711 712 713 714 715 716 717 718 |
# File 'lib/google/apis/reseller_v1/service.rb', line 706 def list_subscriptions(customer_auth_token: nil, customer_id: nil, customer_name_prefix: nil, max_results: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'apps/reseller/v1/subscriptions', ) command.response_representation = Google::Apis::ResellerV1::Subscriptions::Representation command.response_class = Google::Apis::ResellerV1::Subscriptions command.query['customerAuthToken'] = customer_auth_token unless customer_auth_token.nil? command.query['customerId'] = customer_id unless customer_id.nil? command.query['customerNamePrefix'] = customer_name_prefix unless customer_name_prefix.nil? command.query['maxResults'] = max_results unless max_results.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_customer(customer_id, customer_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ResellerV1::Customer
Updates a customer account's settings. This method supports patch semantics.
You cannot update customerType via the Reseller API, but a "team" customer
can verify their domain and become customerType = "domain". For more
information, see Verify your domain to unlock Essentials features.
176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/google/apis/reseller_v1/service.rb', line 176 def patch_customer(customer_id, customer_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'apps/reseller/v1/customers/{customerId}', ) command.request_representation = Google::Apis::ResellerV1::Customer::Representation command.request_object = customer_object command.response_representation = Google::Apis::ResellerV1::Customer::Representation command.response_class = Google::Apis::ResellerV1::Customer command.params['customerId'] = customer_id unless customer_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#register_resellernotify(service_account_email_address: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ResellerV1::ResellernotifyResource
Registers a Reseller for receiving notifications.
276 277 278 279 280 281 282 283 284 |
# File 'lib/google/apis/reseller_v1/service.rb', line 276 def register_resellernotify(service_account_email_address: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'apps/reseller/v1/resellernotify/register', ) command.response_representation = Google::Apis::ResellerV1::ResellernotifyResource::Representation command.response_class = Google::Apis::ResellerV1::ResellernotifyResource command.query['serviceAccountEmailAddress'] = service_account_email_address unless service_account_email_address.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#start_subscription_paid_service(customer_id, subscription_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ResellerV1::Subscription
Immediately move a 30-day free trial subscription to a paid service subscription. This method is only applicable if a payment plan has already been set up for the 30-day trial subscription. For more information, see manage subscriptions.
754 755 756 757 758 759 760 761 762 763 |
# File 'lib/google/apis/reseller_v1/service.rb', line 754 def start_subscription_paid_service(customer_id, subscription_id, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'apps/reseller/v1/customers/{customerId}/subscriptions/{subscriptionId}/startPaidService', ) command.response_representation = Google::Apis::ResellerV1::Subscription::Representation command.response_class = Google::Apis::ResellerV1::Subscription command.params['customerId'] = customer_id unless customer_id.nil? command.params['subscriptionId'] = subscription_id unless subscription_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#suspend_subscription(customer_id, subscription_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ResellerV1::Subscription
Suspends an active subscription. You can use this method to suspend a paid
subscription that is currently in the ACTIVE state. * For FLEXIBLE
subscriptions, billing is paused. * For ANNUAL_MONTHLY_PAY or
ANNUAL_YEARLY_PAY subscriptions: * Suspending the subscription does not
change the renewal date that was originally committed to. * A suspended
subscription does not renew. If you activate the subscription after the
original renewal date, a new annual subscription will be created, starting on
the day of activation. We strongly encourage you to suspend subscriptions only
for short periods of time as suspensions over 60 days may result in the
subscription being cancelled.
804 805 806 807 808 809 810 811 812 813 |
# File 'lib/google/apis/reseller_v1/service.rb', line 804 def suspend_subscription(customer_id, subscription_id, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'apps/reseller/v1/customers/{customerId}/subscriptions/{subscriptionId}/suspend', ) command.response_representation = Google::Apis::ResellerV1::Subscription::Representation command.response_class = Google::Apis::ResellerV1::Subscription command.params['customerId'] = customer_id unless customer_id.nil? command.params['subscriptionId'] = subscription_id unless subscription_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#unregister_resellernotify(service_account_email_address: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ResellerV1::ResellernotifyResource
Unregisters a Reseller for receiving notifications.
306 307 308 309 310 311 312 313 314 |
# File 'lib/google/apis/reseller_v1/service.rb', line 306 def unregister_resellernotify(service_account_email_address: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'apps/reseller/v1/resellernotify/unregister', ) command.response_representation = Google::Apis::ResellerV1::ResellernotifyResource::Representation command.response_class = Google::Apis::ResellerV1::ResellernotifyResource command.query['serviceAccountEmailAddress'] = service_account_email_address unless service_account_email_address.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#update_customer(customer_id, customer_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ResellerV1::Customer
Updates a customer account's settings. You cannot update customerType via
the Reseller API, but a "team" customer can verify their domain and become
customerType = "domain". For more information, see update a customer's
settings.
217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/google/apis/reseller_v1/service.rb', line 217 def update_customer(customer_id, customer_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:put, 'apps/reseller/v1/customers/{customerId}', ) command.request_representation = Google::Apis::ResellerV1::Customer::Representation command.request_object = customer_object command.response_representation = Google::Apis::ResellerV1::Customer::Representation command.response_class = Google::Apis::ResellerV1::Customer command.params['customerId'] = customer_id unless customer_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |